Package: prettyunits
Title: Pretty, Human Readable Formatting of Quantities
Version: 1.2.0
Authors@R: c(
  person("Gabor", "Csardi", email="csardi.gabor@gmail.com", role=c("aut", "cre")),
  person("Bill", "Denney", email="wdenney@humanpredictions.com", role=c("ctb"), comment=c(ORCID="0000-0002-5759-428X")),
  person("Christophe", "Regouby", email="christophe.regouby@free.fr", role=c("ctb"))
  )
Description: Pretty, human readable formatting of quantities.
    Time intervals: '1337000' -> '15d 11h 23m 20s'.
    Vague time intervals: '2674000' -> 'about a month ago'.
    Bytes: '1337' -> '1.34 kB'.
    Rounding: '99' with 3 significant digits -> '99.0'
    p-values: '0.00001' -> '<0.0001'.
    Colors: '#FF0000' -> 'red'.
    Quantities: '1239437' -> '1.24 M'.
License: MIT + file LICENSE
URL: https://github.com/r-lib/prettyunits
BugReports: https://github.com/r-lib/prettyunits/issues
Depends: R(>= 2.10)
Suggests: codetools, covr, testthat
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-09-24 10:53:19 UTC; gaborcsardi
Author: Gabor Csardi [aut, cre],
  Bill Denney [ctb] (<https://orcid.org/0000-0002-5759-428X>),
  Christophe Regouby [ctb]
Maintainer: Gabor Csardi <csardi.gabor@gmail.com>
Repository: CRAN
Date/Publication: 2023-09-24 21:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 15:44:33 UTC; unix
