# Generated by roxygen2: do not edit by hand

export(compute_bytes)
export(compute_num)
export(pretty_bytes)
export(pretty_color)
export(pretty_colour)
export(pretty_dt)
export(pretty_ms)
export(pretty_num)
export(pretty_p_value)
export(pretty_round)
export(pretty_sec)
export(pretty_signif)
export(time_ago)
export(vague_dt)
importFrom(grDevices,col2rgb)
importFrom(grDevices,convertColor)
